# Aliyun Trace

[![pypi](https://badge.fury.io/py/openinference-semantic-conventions.svg)](https://pypi.org/project/openinference-semantic-conventions/)

This library contains code for the Aliyun Trace that manually creates a trace for the LLM.